packed_bytes_per_vector

Function packed_bytes_per_vector 

pub fn packed_bytes_per_vector(dim: usize, nbits: u32) -> usize
Number of bytes required to pack dim codes at nbits bits each.

Panics if nbits is not one of the supported packed widths.